@@ -18,4 +18,5 @@
 
 //#include <stdlib.h>
 
-static GdkSeat *toGdkSeat(void *p) { return ((GdkSeat *)p); }
\ No newline at end of file
+// Type Casting
+static GdkMonitor *toGdkMonitor(void *p) { return (GDK_MONITOR(p)); }
