@@ -21,6 +21,7 @@ package gtk
 import (
 	"fmt"
 	"log"
+	"runtime"
 	"testing"
 	"time"
 
@@ -32,6 +33,37 @@ func init() {
 	Init(nil)
 }
 
+// TestConnectNotifySignal ensures that property notification signals (those
+// whose name begins with "notify::") are queried by the name "notify" (with the
+// "::" and the property name omitted). This is because the signal is "notify"
+// and the characters after the "::" are not recognized by the signal system.
+//
+// See
+// https://developer.gnome.org/gobject/stable/gobject-The-Base-Object-Type.html#GObject-notify
+// for background, and
+// https://developer.gnome.org/gobject/stable/gobject-Signals.html#g-signal-new
+// for the specification of valid signal names.
+func TestConnectNotifySignal(t *testing.T) {
+	runtime.LockOSThread()
+
+	// Create any GObject that has defined properties.
+	spacing := 0
+	box, _ := BoxNew(ORIENTATION_HORIZONTAL, spacing)
+
+	// Connect to a "notify::" signal to listen on property changes.
+	box.Connect("notify::spacing", func() {
+		MainQuit()
+	})
+
+	glib.IdleAdd(func() bool {
+		spacing++
+		box.SetSpacing(spacing)
+		return true
+	})
+
+	Main()
+}
+
 // TestBoolConvs tests the conversion between Go bools and gboolean
 // types.
 func TestBoolConvs(t *testing.T) {
@@ -838,7 +870,7 @@ func TestBuilder(t *testing.T) {
 		},
 	})
 
-	go button.Emit("clicked")
+	go button.Emit("clicked", glib.TYPE_STRING)
 
 	select {
 	case <-done:
@@ -873,3 +905,27 @@ func TestTextTagEvent(t *testing.T) {
 	}
 
 }
+
+func TestCssProviderParsingErrorEvent(t *testing.T) {
+	css, err := CssProviderNew()
+	if err != nil {
+		t.Error("could not create CSS provider")
+	}
+
+	done := make(chan bool)
+
+	css.Connect("parsing-error",
+		// The first argument must be a CssProvider
+		func(css *CssProvider) {
+			done <- true
+		},
+	)
+
+	go css.LoadFromData(";")
+
+	select {
+	case <-done:
+	case <-time.After(1 * time.Second):
+		t.Error("Failed to call callback")
+	}
+}
