@@ -10,6 +10,8 @@ import "C"
 import (
 	"runtime"
 	"unsafe"
+
+	"github.com/gotk3/gotk3/glib"
 )
 
 // PaperSizeNewFromIpp is a wrapper around gtk_paper_size_new_from_ipp().
@@ -23,7 +25,7 @@ func PaperSizeNewFromIPP(name string, width, height float64) (*PaperSize, error)
 	}
 
 	t := &PaperSize{c}
-	runtime.SetFinalizer(t, (*PaperSize).free)
+	runtime.SetFinalizer(t, func(v *PaperSize) { glib.FinalizerStrategy(v.free) })
 	return t, nil
 }
 
