@@ -653,9 +653,7 @@ func WindowListToplevels() *glib.List {
 	glist.DataWrapper(func(ptr unsafe.Pointer) interface{} {
 		return wrapWindow(glib.Take(ptr))
 	})
-	runtime.SetFinalizer(glist, func(l *glib.List) {
-		l.Free()
-	})
+	runtime.SetFinalizer(glist, func(v *glib.List) { glib.FinalizerStrategy(v.Free) })
 	return glist
 }
 
@@ -670,9 +668,7 @@ func WindowGetDefaultIconList() *glib.List {
 	glist.DataWrapper(func(ptr unsafe.Pointer) interface{} {
 		return &gdk.Pixbuf{glib.Take(ptr)}
 	})
-	runtime.SetFinalizer(glist, func(l *glib.List) {
-		l.Free()
-	})
+	runtime.SetFinalizer(glist, func(v *glib.List) { glib.FinalizerStrategy(v.Free) })
 	return glist
 }
 
@@ -687,9 +683,7 @@ func (v *Window) GetIconList() *glib.List {
 	glist.DataWrapper(func(ptr unsafe.Pointer) interface{} {
 		return &gdk.Pixbuf{glib.Take(ptr)}
 	})
-	runtime.SetFinalizer(glist, func(l *glib.List) {
-		l.Free()
-	})
+	runtime.SetFinalizer(glist, func(v *glib.List) { glib.FinalizerStrategy(v.Free) })
 	return glist
 }
 
