@@ -1,4 +1,4 @@
-// +build !pango_1_42
+// +build !pango_1_36,!pango_1_38,!pango_1_40,!pango_1_42
 
 package pango
 
@@ -13,6 +13,6 @@ var (
 func AttrInsertHyphensNew(insertHyphens bool) *Attribute {
 	c := C.pango_attr_insert_hyphens_new(gbool(insertHyphens))
 	attr := new(Attribute)
-	attr.pangoAttribute = c
+	attr.internal = c
 	return attr
 }
