@@ -188,11 +188,7 @@ func (v *Layout) SetAttributes(attrs *AttrList) {
 // GetAttributes is a wrapper around pango_layout_get_attributes().
 func (v *Layout) GetAttributes() *AttrList {
 	c := C.pango_layout_get_attributes(v.native())
-
-	attrList := new(AttrList)
-	attrList.pangoAttrList = (*C.PangoAttrList)(c)
-
-	return attrList
+	return wrapAttrList(c)
 }
 
 // SetText is a wrapper around pango_layout_set_text().
@@ -312,7 +308,7 @@ func (v *Layout) GetTabs() (*TabArray, error) {
 		return nil, nilPtrErr
 	}
 	ta := wrapTabArray(c)
-	runtime.SetFinalizer(ta, (*TabArray).free)
+	runtime.SetFinalizer(ta, func(v *TabArray) { glib.FinalizerStrategy(v.free) })
 	return ta, nil
 }
 
@@ -359,7 +355,7 @@ func TabArrayNew(initialSize int, positionsInPixels bool) *TabArray {
 	c := C.pango_tab_array_new(C.gint(initialSize), gbool(positionsInPixels))
 
 	tabArray := new(TabArray)
-	runtime.SetFinalizer(tabArray, (*TabArray).free)
+	runtime.SetFinalizer(tabArray, func(v *TabArray) { glib.FinalizerStrategy(v.free) })
 	tabArray.pangoTabArray = (*C.PangoTabArray)(c)
 	return tabArray
 }
@@ -369,7 +365,7 @@ func TabArrayNew(initialSize int, positionsInPixels bool) *TabArray {
 // 	c := C.pango_tab_array_new_with_positions(C.gint(size), gbool(positionsInPixels), ...)
 
 // 	tabArray := new(TabArray)
-//	runtime.SetFinalizer(e, (*TabArray).free)
+//	runtime.SetFinalizer(e, func(v *TabArray) { glib.FinalizerStrategy(v.free) })
 // 	tabArray.pangoTabArray = (*C.PangoTabArray)(c)
 // 	return tabArray
 // }
@@ -381,7 +377,7 @@ func (v *TabArray) Copy() (*TabArray, error) {
 		return nil, nilPtrErr
 	}
 	ta := wrapTabArray(c)
-	runtime.SetFinalizer(ta, (*TabArray).free)
+	runtime.SetFinalizer(ta, func(v *TabArray) { glib.FinalizerStrategy(v.free) })
 	return ta, nil
 }
 
